pub(crate) struct ConstVidKey<'db> {
pub(crate) vid: ConstVid,
pub(crate) phantom: PhantomData<Const<'db>>,
}Fields
vid: ConstVidphantom: PhantomData<Const<'db>>Trait Implementations
Sourceimpl<'db> Clone for ConstVidKey<'db>
impl<'db> Clone for ConstVidKey<'db>
Sourcefn clone(&self) -> ConstVidKey<'db>
fn clone(&self) -> ConstVidKey<'db>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'db> Debug for ConstVidKey<'db>
impl<'db> Debug for ConstVidKey<'db>
Sourceimpl<'db> From<ConstVid> for ConstVidKey<'db>
impl<'db> From<ConstVid> for ConstVidKey<'db>
Sourceimpl<'db> PartialEq for ConstVidKey<'db>
impl<'db> PartialEq for ConstVidKey<'db>
Sourcefn eq(&self, other: &ConstVidKey<'db>) -> bool
fn eq(&self, other: &ConstVidKey<'db>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'db> UnifyKey for ConstVidKey<'db>
impl<'db> UnifyKey for ConstVidKey<'db>
type Value = ConstVariableValue<'db>
fn index(&self) -> u32
fn from_index(i: u32) -> Self
fn tag() -> &'static str
fn order_roots(
a: Self,
a_value: &Self::Value,
b: Self,
b_value: &Self::Value,
) -> Option<(Self, Self)>
fn order_roots( a: Self, a_value: &Self::Value, b: Self, b_value: &Self::Value, ) -> Option<(Self, Self)>
You should return first the key that should be used as root,
then the other key (that will then point to the new root). Read more
impl<'db> Copy for ConstVidKey<'db>
impl<'db> StructuralPartialEq for ConstVidKey<'db>