pub(crate) struct RegionVidKey<'db> {
pub(crate) vid: RegionVid,
pub(crate) phantom: PhantomData<RegionVariableValue<'db>>,
}Fields
vid: RegionVidphantom: PhantomData<RegionVariableValue<'db>>Trait Implementations
Sourceimpl<'db> Clone for RegionVidKey<'db>
impl<'db> Clone for RegionVidKey<'db>
Sourcefn clone(&self) -> RegionVidKey<'db>
fn clone(&self) -> RegionVidKey<'db>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'db> Debug for RegionVidKey<'db>
impl<'db> Debug for RegionVidKey<'db>
Sourceimpl<'db> From<RegionVid> for RegionVidKey<'db>
impl<'db> From<RegionVid> for RegionVidKey<'db>
Sourceimpl<'db> PartialEq for RegionVidKey<'db>
impl<'db> PartialEq for RegionVidKey<'db>
Sourcefn eq(&self, other: &RegionVidKey<'db>) -> bool
fn eq(&self, other: &RegionVidKey<'db>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'db> UnifyKey for RegionVidKey<'db>
impl<'db> UnifyKey for RegionVidKey<'db>
type Value = RegionVariableValue<'db>
fn index(&self) -> u32
fn from_index(i: u32) -> Self
fn tag() -> &'static str
fn order_roots(
a: Self,
a_value: &Self::Value,
b: Self,
b_value: &Self::Value,
) -> Option<(Self, Self)>
fn order_roots( a: Self, a_value: &Self::Value, b: Self, b_value: &Self::Value, ) -> Option<(Self, Self)>
You should return first the key that should be used as root,
then the other key (that will then point to the new root). Read more
impl<'db> Copy for RegionVidKey<'db>
impl<'db> StructuralPartialEq for RegionVidKey<'db>